Developer Documentation
=======================

This information is for developers and admins of this site.

We use django-bldtool(Sphinx) for the documentation system. This is part of the generated documentation.  The documentation (both user and developer) is created with as a django-admin command: ``python manage.py doc``.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   All Modules <apidoc/modules>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
